//  File:  FileIO\FileIO.java

import java.io.*;

/**
 * Show how to do simple stream-oriented input/output in Java.<br>
 * Show how to use StreamTokenizer to parse input.<br>
 * Show how to read line-at-a-time.
 * 
 * Note: Java 1.5's Scanner class may be helpful...
 *
 * @author Bary W Pollack
 * @version version 02/25/01 - 17:00 - Modified
 */

public class FileIO {

    /**
     * Name of the input file from which data is to be read.
     */
    static final String sInFile  = "input.txt";

    /**
     * Name of the output file to which data is to be written.
     */
    static final String sOutFile = "output.txt";

    /**
     * Show how to set up a StreamTokenizer in order to read from
     * an input stream and properly parse the data.<br>
     * Show how to do simple stream-oriented I/O to and from files.<br>
     * Show how to read from a file one line at a time.
     */

    FileIO() {
        try {
            // =============================================================
            // First, demonstrate simple stream input/output...
            // Read until EOF...
            // =============================================================

            // set up the input in two steps because we want to be able to
            // invoke the reader's close() method later on...
            FileReader reader = new FileReader(sInFile);
            StreamTokenizer tokens = new StreamTokenizer(
                                         new BufferedReader(reader));
            // tell the tokenizer that we want to parse numbers "properly"
            tokens.parseNumbers();
            tokens.eolIsSignificant(true);
            tokens.ordinaryChar('/');

            // set up the output writer
            PrintWriter outs = new PrintWriter(
                                   new BufferedWriter(
                                       new FileWriter(sOutFile)), true);

            System.out.println("TokenType  _______Value_______\n");
            outs.println("TokenType  _______Value_______");
            outs.println();

            int next = 0;
            while ((next = tokens.nextToken()) != StreamTokenizer.TT_EOF) {
                switch (next) {
                    case StreamTokenizer.TT_WORD:
                        System.out.println("WORD:      " + tokens.sval);
                        outs.println("WORD:      " + tokens.sval);
                        break;
                    // Note how scientific notation is (not) handled!
                    case StreamTokenizer.TT_NUMBER:
                        System.out.println("NUMBER:    " + tokens.nval);
                        outs.println("NUMBER:    " + tokens.nval);
                        break;
                    case StreamTokenizer.TT_EOL:
                        System.out.println("EOL");
                        outs.println("EOL");
                        break;
                    default:
                        System.out.println("OTHER:     " + (char) next);
                        outs.println("OTHER:     " + (char) next);
                        break;
                }
            }

            reader.close();
            outs.close();

            // =============================================================
            // Now, demonstrate line-oriented input...
            // =============================================================

            System.out.println("\n\nBegin echoing input...\n");
            BufferedReader line = new BufferedReader(
                                      new FileReader(sInFile));
            String s;
            while ((s = line.readLine()) != null)
                System.out.println("<" + s + ">");
            line.close();

        } catch(EOFException e) {
            System.out.println("\nEnd of File encountered\n\n" + e);

        } catch(FileNotFoundException e) {
            System.out.println("\nFile Not Found encountered\n\n" + e);

        } catch(IOException e) {
            System.out.println("\nIO exception encountered\n\n" + e);
        }
    }

    /**
     * Runs FileIO()...  There should be a pre-existing file, called
     * input.txt, in the current directory.  An output file,
     * output.txt, will be created in the current directory as a
     * result of executing the program.<br>
     * This program reads from input.txt, parsing the input as it
     * goes, and displays the items that it reads both on stdout
     * as well as writing a copy of this information in output.txt.<br>
     * Then the program reads from input.txt line-at-a-time,
     * echoing the lines to stdout.
     *
     * @param args unused
     */

    static public void main(String args[]) {
        System.out.println("***** FileIO Demo ***** \n\n"
                         + "Reading and writing files...\n");

        new FileIO();

        System.out.println("\nFini... \n");
    }
}


/*  Screen output from running this program:

***** FileIO Demo ***** 

Reading and writing files...

TokenType  _______Value_______

WORD:      aStringOfCharacters
EOL
WORD:      a
WORD:      character
EOL
EOL
NUMBER:    -9.0
NUMBER:    12345.0
NUMBER:    3.14159
NUMBER:    13.57
WORD:      E-24
EOL
WORD:      somePunctuation
OTHER:     <
OTHER:     ,
OTHER:     :
OTHER:     ;
OTHER:     #
OTHER:     ~
OTHER:     !
OTHER:     (
OTHER:     @
OTHER:     )
OTHER:     *
OTHER:     ^
OTHER:     /
OTHER:     +
OTHER:     -
OTHER:     =
EOL
WORD:      lastLineOfInput


Begin echoing input...

<aStringOfCharacters>
<a       character>
<>
<-9 12345 3.14159 13.57E-24>
<somePunctuation<,:;#~!(@)*^/+-=>
<lastLineOfInput>

Fini... 

..... */
